namespace Siberix.Examples
{
	using System;
	using System.Collections.Generic;

	class Example
	{
		private class Person
		{
			public string Name { get; set; }
			public DateTime Birthday { get; set; }
			public int Level { get; set; }
			public List<Task> Tasks { get; set; }
		}

		private class Task
		{
			public string Id { get; set; }
			public string Description { get; set; }
		}

		private class ValueFormatter : Siberix.Report.Data.IValueFormatter
		{
			public string Id
			{
				get
				{
					return "vf1";
				}
			}

			public string Format(object value)
			{
				if (value != null)
				{
					DateTime dt = (DateTime)value;

					return "[ " + dt.Year + " / " + dt.ToString("MMM") + " / " + dt.Day + " ]";
				}

				return null;
			}
		}

		static void Main(string[] args)
		{
			Person person1 = new Person() { Name = "John", Level = 3 };
			Person person2 = new Person() { Name = "Alex", Level = 2 };
			Person person3 = new Person() { Name = "Bob", Level = 7 };
			Person person4 = new Person() { Name = "Scott", Level = 1, Birthday = new DateTime(1965, 10, 23) };

			List<Task> tasks = new List<Task>();

			tasks.Add(new Task() { Id = "1-A11", Description = "Task 1" });
			tasks.Add(new Task() { Id = "2-B22", Description = "Task 2" });
			tasks.Add(new Task() { Id = "3-C33", Description = "Task 3" });
			tasks.Add(new Task() { Id = "4-D44", Description = "Task 4" });

			Person person5 = new Person() { Name = "Nick", Level = 1, Birthday = new DateTime(1975, 7, 16), Tasks = tasks };

			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			report.DataContext = new Siberix.Report.Data.DataContext("dc4", person4);

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(15), Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(15), Siberix.Graphics.Brushes.Red);

			// Binding to the text.DataContext
			Siberix.Report.Text.IText text = section.AddText();
			text.DataContext = new Siberix.Report.Data.DataContext("dc1", person1);
			text.Binding = new Siberix.Report.Data.DataBinding("Name");
			text.Style = style1;



			// Binding with Formatter
			text = section.AddText();
			text.DataContext = new Siberix.Report.Data.DataContext("dc2", person2);
			text.Binding = new Siberix.Report.Data.DataBinding("Level", "Level: {0}");
			text.Style = style1;



			// Binding text to the parent DataContext with ValueFormatter
			text = section.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Birthday", "Birthday: *** {0} ***", new ValueFormatter());
			text.Style = style1;



			// Binding text to a specific DataContext
			text = section.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding(new Siberix.Report.Data.DataContext("dc3", person3), "Name", "Name: {0}");
			text.Style = style1;



			// Binding repeater to a collection of objects
			Siberix.Report.Repeater.IRepeater repeater = section.AddRepeater();
			repeater.DataContext = new Siberix.Report.Data.DataContext("dc5", person5);
			repeater.Binding = new Siberix.Report.Data.DataBinding("Tasks");
			repeater.Spacings.Top = 25;

			// Repeater item template
			Siberix.Report.Repeater.IItemTemplate repeaterItemTemplate = repeater.AddItemTemplate();

			text = repeaterItemTemplate.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Description");
			text.Style = style1;



			// Binding list to a collection of objects
			Siberix.Report.List.IList list = section.AddList();
			list.DataContext = new Siberix.Report.Data.DataContext("dc5", person5);
			list.Binding = new Siberix.Report.Data.DataBinding("Tasks");
			list.Spacings.Top = 25;

			// List item template
			Siberix.Report.List.IItemTemplate listItemTemplate = list.AddItemTemplate();

			text = listItemTemplate.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Id");
			text.Style = style1;

			text = listItemTemplate.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Description", ": [ {0} ]");
			text.Style = style2;



			// Binding grid to a collection of objects
			Siberix.Report.Grid.IGrid grid = section.AddGrid();
			grid.DataContext = new Siberix.Report.Data.DataContext("dc5", person5);
			grid.Binding = new Siberix.Report.Data.DataBinding("Tasks");
			grid.Spacings.Top = 25;
			grid.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);

			Siberix.Report.Grid.IColumn column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(20);

			column = grid.AddColumn();
			column.Width = new Siberix.Report.RelativeWidth(80);

			Siberix.Report.Grid.IHeader header = grid.AddHeader();

			Siberix.Report.Grid.IRow row = header.AddRow();

			Siberix.Report.Grid.ICell cell = row.AddCell();
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Paddings.All = 5;
			cell.Background.Brush = Siberix.Graphics.Brushes.LightSkyBlue;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("Id");

			cell = row.AddCell();
			cell.ColSpan = 4;
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Paddings.All = 5;
			cell.Background.Brush = Siberix.Graphics.Brushes.LightYellow;

			text = cell.AddText();
			text.Style = style1;
			text.AddContent("Description");

			// Grid row template
			Siberix.Report.Grid.IRowTemplate gridRowTemplate = grid.AddRowTemplate();

			cell = gridRowTemplate.AddCell();
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Id");
			text.Style = style1;

			cell = gridRowTemplate.AddCell();
			cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
			cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
			cell.Paddings.All = 5;

			text = cell.AddText();
			text.Binding = new Siberix.Report.Data.DataBinding("Description", "--- {0} ---");
			text.Style = style2;

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Report.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}