namespace Siberix.Examples
{
	using System;
	using System.Collections.Generic;

	class Example : Siberix.Report.Data.IDataProvider
	{
		private Siberix.Report.Data.IDataContext _dc1;
		private Siberix.Report.Data.IDataContext _dc2;
		private Siberix.Report.Data.IDataContext _dc3;
		private Siberix.Report.Data.IDataContext _dc4;
		private Siberix.Report.Data.IDataContext _dc5;
		private Siberix.Report.Data.IValueFormatter _vf1;
		private Siberix.Report.Data.IValueFormatter _vf2;
		private Siberix.Report.Data.ITemplateSelector _ts1;
		private Siberix.Report.Data.ITemplateSelector _ts2;

		private class Person
		{
			public string Name { get; set; }
			public DateTime Birthday { get; set; }
			public int Level { get; set; }
			public List<Task> Tasks { get; set; }
		}

		private class Task
		{
			public string Id { get; set; }
			public string Description { get; set; }
		}

		private class ValueFormatter1 : Siberix.Report.Data.IValueFormatter
		{
			public string Id
			{
				get
				{
					return "vf1";
				}
			}

			public string Format(object value)
			{
				if (value != null)
				{
					DateTime dt = (DateTime)value;

					return "[ " + dt.Year + " / " + dt.ToString("MMM") + " / " + dt.Day + " ]";
				}

				return null;
			}
		}

		private class ValueFormatter2 : Siberix.Report.Data.IValueFormatter
		{
			public string Id
			{
				get
				{
					return "vf2";
				}
			}

			public string Format(object value)
			{
				if (value != null)
				{

					return "< " + (string)value + " >";
				}

				return null;
			}
		}

		private class TemplateSelector1 : Siberix.Report.List.IItemTemplateSelector
		{
			public string Id
			{
				get
				{
					return "ts1";
				}
			}

			public Siberix.Report.List.IItemTemplate SelectItemTemplate(object item, int index, List<Siberix.Report.List.IItemTemplate> templates, Siberix.Report.List.IItemTemplateFactory factory)
			{
				if (index == 1)
					return templates[1];

				if (index == 3)
				{
					Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(15), Siberix.Graphics.Brushes.Blue);

					Siberix.Report.List.IItemTemplate template = factory.CreateItemTemplate();

					Siberix.Report.Text.IText text = template.AddText();
					text.Binding = new Siberix.Report.Data.DataBinding("Description", "New Item Template: {0}");
					text.Style = style1;

					return template;
				}

				return templates[0];
			}
		}

		private class TemplateSelector2 : Siberix.Report.Grid.IRowTemplateSelector
		{
			public string Id
			{
				get
				{
					return "ts2";
				}
			}

			public Siberix.Report.Grid.IRowTemplate SelectRowTemplate(object item, int index, List<Siberix.Report.Grid.IRowTemplate> templates, Siberix.Report.Grid.IRowTemplateFactory factory)
			{
				if (index == 1)
					return templates[1];

				if (index == 3)
				{
					Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(14), Siberix.Graphics.Brushes.Blue);
					Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(14), Siberix.Graphics.Brushes.White);

					Siberix.Report.Grid.IRowTemplate template = factory.CreateRowTemplate();

					Siberix.Report.Grid.ICell cell = template.AddCell();
					cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
					cell.Paddings.All = 5;

					Siberix.Report.Text.IText text = cell.AddText();
					text.Binding = new Siberix.Report.Data.DataBinding("Id", "{0}");
					text.Style = style1;

					cell = template.AddCell();
					cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
					cell.Paddings.All = 5;
					cell.Background.Brush = Siberix.Graphics.Brushes.YellowGreen;

					text = cell.AddText();
					text.Binding = new Siberix.Report.Data.DataBinding("Description", "New Row Template: {0}");
					text.Style = style2;

					return template;
				}

				return templates[0];
			}
		}

		static void Main(string[] args)
		{
			Example example = new Example();

			example.GenerateReport();

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}

		public void GenerateReport()
		{
			Person person1 = new Person() { Name = "John", Level = 3 };
			Person person2 = new Person() { Name = "Alex", Level = 2 };
			Person person3 = new Person() { Name = "Bob", Level = 7 };
			Person person4 = new Person() { Name = "Scott", Level = 1, Birthday = new DateTime(1965, 10, 23) };

			List<Task> tasks = new List<Task>();

			tasks.Add(new Task() { Id = "1-A11", Description = "Task 1" });
			tasks.Add(new Task() { Id = "2-B22", Description = "Task 2" });
			tasks.Add(new Task() { Id = "3-C33", Description = "Task 3" });
			tasks.Add(new Task() { Id = "4-D44", Description = "Task 4" });
			tasks.Add(new Task() { Id = "5-E55", Description = "Task 5" });

			Person person5 = new Person() { Name = "Nick", Level = 1, Birthday = new DateTime(1975, 7, 16), Tasks = tasks };

			_dc1 = new Siberix.Report.Data.DataContext("dc1", person4);
			_dc2 = new Siberix.Report.Data.DataContext("dc2", person1);
			_dc3 = new Siberix.Report.Data.DataContext("dc3", person3);
			_dc4 = new Siberix.Report.Data.DataContext("dc4", person2);
			_dc5 = new Siberix.Report.Data.DataContext("dc5", person5);

			_vf1 = new ValueFormatter1();
			_vf2 = new ValueFormatter2();

			_ts1 = new TemplateSelector1();
			_ts2 = new TemplateSelector2();

			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			report.DataProvider = this;

			// Load
			report.Load("../../Report.xml");

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);
		}

		public Siberix.Report.Data.IDataContext GetDataContext(string id)
		{
			if (string.IsNullOrEmpty(id))
				return null;

			switch (id)
			{
				case "dc1":
					return _dc1;

				case "dc2":
					return _dc2;

				case "dc3":
					return _dc3;

				case "dc4":
					return _dc4;

				case "dc5":
					return _dc5;
			}

			return null;
		}

		public Siberix.Report.Data.ITemplateSelector GetTemplateSelector(string id)
		{
			if (string.IsNullOrEmpty(id))
				return null;

			if (id == "ts1")
				return _ts1;

			if (id == "ts2")
				return _ts2;

			return null;
		}

		public Siberix.Report.Data.IValueFormatter GetValueFormatter(string id)
		{
			if (string.IsNullOrEmpty(id))
				return null;

			switch (id)
			{
				case "vf1":
					return _vf1;

				case "vf2":
					return _vf2;
			}

			return null;
		}
	}
}