using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(10), Siberix.Graphics.Brushes.Red);

			// Site
			Siberix.Report.ISite site = section.AddSite();
			site.Width = new Siberix.Report.RelativeWidth(100);
			site.Height = new Siberix.Report.RelativeHeight(100);
			site.Borders = new Siberix.Report.Borders(new Siberix.Graphics.Pen(Siberix.Graphics.Colors.Black, 1, Siberix.Graphics.DashStyle.Dot), 5);
			site.Paddings.All = 5;

			Siberix.Report.Text.IText text = site.AddText(10, 10);
			text.Width = new Siberix.Report.DirectWidth(200);
			text.Style = style1;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.Spacings.All = 10;
			text.AddContent("(Left:10, Top:10) ", style2);
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			text = site.AddText(150, 150, 45);
			text.Width = new Siberix.Report.DirectWidth(200);
			text.Style = style1;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.Spacings.All = 10;
			text.AddContent("(Left:150, Top:150, Angle:45) ", style2);
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			text = site.AddText(250, 100, -15);
			text.Width = new Siberix.Report.DirectWidth(200);
			text.Style = style1;
			text.Alignment = Siberix.Report.TextAlignment.Justify;
			text.Spacings.All = 10;
			text.AddContent("(Left:250, Top:100, Angle:-15) ", style2);
			text.AddContent("Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

			Siberix.Report.IImage image = site.AddImage(new Siberix.Graphics.Image("../../image.jpg"), 335, 240, -35);
			image.Width = new Siberix.Report.DirectWidth(150);

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Document.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}