using System.Collections.Generic;

namespace Siberix.Examples
{
	using System;

	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);

			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Red);
			style2.FontVariant = Siberix.Report.FontVariant.Subscript;

			Siberix.Graphics.Image img = new Siberix.Graphics.Image("../../image.jpg");

			System.Random rnd = new System.Random();

			for (int i = 0; i < 5; i++)
			{
				// Slot
				Siberix.Report.Slot.ISlot slot = section.AddSlot();
				slot.StretchOnBreak = true;
				slot.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
				slot.Spacings.Bottom = 5;

				Siberix.Report.Slot.ICell cell = slot.AddCell();
				cell.Width = new Siberix.Report.RelativeWidth(30);
				cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
				cell.Background.Brush = Siberix.Graphics.Brushes.WhiteSmoke;
				cell.Paddings.All = 5;

				Siberix.Report.Text.IText text = cell.AddText();
				text.Style = style1;
				text.AddContent("Slot");
				text.AddContent((i + 1).ToString(), style2);
				text.AddLineBreak();
				text.AddContent("cell");
				text.AddContent("1", style2);
				text.AddContent(" content...");

				Siberix.Report.IGroup group = cell.AddGroup();
				group.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.DarkBlue);
				group.Width = new Siberix.Report.RelativeWidth(90);
				group.Spacings.Top = 10;

				Siberix.Report.IImage image = group.AddImage(img);
				image.Width = new Siberix.Report.RelativeWidth(100);

				cell = slot.AddCell();
				cell.Width = new Siberix.Report.DirectWidth(100);
				cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
				cell.Paddings.All = 5;
				cell.Background.Brush = Siberix.Graphics.Brushes.Lavender;

				text = cell.AddText();
				text.Style = style1;
				text.AddContent("cell");
				text.AddContent("2", style2);
				text.AddContent(" content... Amarone is produced in the Veneto region of northern Italy using a unique winemaking technique. Newly harvested grapes are laid on straw mats and left to dry over the course of several months - resulting in a wine with a very distinctive \"raisiny\" flavor.");

				int j = 0;
				int cnt = rnd.Next(5);

				while (j < cnt)
				{
					j++;

					text.AddLineBreak();
					text.AddContent("... extra text line");
					text.AddContent(j.ToString(), style2);
				}

				cell = slot.AddCell();
				cell.Width = new Siberix.Report.RelativeWidth(70);
				cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle;
				cell.Borders = new Siberix.Report.Borders(Siberix.Graphics.Pens.Black);
				cell.Background.Brush = Siberix.Graphics.Brushes.WhiteSmoke;
				cell.Paddings.All = 5;

				text = cell.AddText();
				text.Style = style1;
				text.AddContent("cell");
				text.AddContent("3", style2);
				text.AddContent(" content...");

				j = 0;
				cnt = rnd.Next(5);

				while (j < cnt)
				{
					j++;

					text.AddLineBreak();
					text.AddContent("... extra text line");
					text.AddContent(j.ToString(), style2);
				}
			}

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Report.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}