using System;
using System.IO;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(10), Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(85), new Siberix.Graphics.SolidColorBrush(new Siberix.Graphics.Color(240, 240, 240)));

			// Page Numbering
			Siberix.Report.Section.IFooter footer = section.AddFooter();
			footer.Height = new Siberix.Report.DirectHeight(30);

			Siberix.Report.IPageNumber pn = footer.AddPageNumber(600, 10);
			pn.Style = style1;
			pn.Format = Siberix.Report.NumberFormat.Decimal;
			pn.Template = "Page {0} of {1}";
			pn.Alignment = Siberix.Report.NumberAlignment.Right;

			// Watermark
			Siberix.Report.Section.IWatermark watermark = section.AddWatermark();
			watermark.Repeat = true;

			Siberix.Graphics.Image image = new Siberix.Graphics.Image("../../bgimage.png");
			Siberix.Report.IImage img = watermark.AddImage(image, 0, 600);

			Siberix.Report.Text.IText text = watermark.AddText(200, 500, -45);
			text.Style = style2;
			text.AddContent("Watermark");

			section.AddPageBreak();
			section.AddPageBreak();

			// Publish
			report.Publish("Document.pdf", Report.FileFormat.PDF);
			report.Publish("Document.xps", Report.FileFormat.XPS);

			// Save
			report.Save("Report.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}
	}
}