using System;

namespace Siberix.Examples
{
	class Example
	{
		static void Main(string[] args)
		{
			// Report
			Siberix.Report.Report report = new Siberix.Report.Report();

			// Info
			report.Info.Title = "Example";
			report.Info.Author = "Siberix Technologies, Canada";
			report.Info.Creator = "Siberix Report Writer";
			report.Info.Copyright = "2003-2012 Siberix Technologies, Canada";

			// Section
			Siberix.Report.Section.ISection section = report.AddSection();
			section.Size = Siberix.Report.PageSize.Letter;
			section.Spacings.All = 35;

			// Styles
			Siberix.Report.Text.Style style1 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.Arial(12), Siberix.Graphics.Brushes.Black);
			Siberix.Report.Text.Style style2 = new Siberix.Report.Text.Style(new Siberix.Graphics.Fonts.TimesNewRomanBold(450), new Siberix.Graphics.LinearGradientBrush(Siberix.Graphics.Colors.Yellow, Siberix.Graphics.Colors.Red, 15F));

			// Page Numbering
			Siberix.Report.Section.IFooter footer = section.AddFooter();
			footer.Height = new Siberix.Report.DirectHeight(30);

			Siberix.Report.IPageNumber pn = footer.AddPageNumber(600, 5);
			pn.Style = style1;
			pn.Format = Siberix.Report.NumberFormat.Decimal;
			pn.Template = "Page {0} of {1}";
			pn.Alignment = Siberix.Report.NumberAlignment.Right;

			for (int i = 1; i < 4; i++)
			{
				Siberix.Report.Text.IText text = section.AddText();
				text.Style = style2;
				text.Spacings.Left = 150;
				text.Spacings.Top = 100;
				text.AddContent(i.ToString());

				if (i < 3)
					section.AddPageBreak();
			}

			// Generate
			Siberix.Report.IPageCollection pages = report.Generate();

			float scale = 0.25F; // 25%

			int pageNumber = 1;

			foreach (Siberix.Report.IPage page in pages)
			{
				SavePNG(page, scale, pageNumber);
				SaveEMF(page, scale, pageNumber);

				pageNumber++;
			}

			// Publish
			report.Publish("Document.pdf", Siberix.Report.FileFormat.PDF);
			report.Publish("Document.xps", Siberix.Report.FileFormat.XPS);

			// Save
			report.Save("Document.xml");

			// View
			System.Diagnostics.Process process = new System.Diagnostics.Process();
			System.Diagnostics.ProcessStartInfo info = new System.Diagnostics.ProcessStartInfo("Document.pdf");
			process.StartInfo = info;
			process.Start();
		}

		private static void SavePNG(Siberix.Report.IPage page, float scale, int pageNumber)
		{
			int width = (int)Siberix.Report.Utils.PointsToPixels(page.Width * scale);
			int height = (int)Siberix.Report.Utils.PointsToPixels(page.Height * scale);

			System.Drawing.Bitmap bmp = new System.Drawing.Bitmap(width, height, System.Drawing.Imaging.PixelFormat.Format24bppRgb);

			System.Drawing.Graphics g = System.Drawing.Graphics.FromImage(bmp);

			Siberix.Wrappers.GDIPlus.Graphics graphics = new Siberix.Wrappers.GDIPlus.Graphics(g);

			graphics.Scale(scale, scale);

			page.Draw(graphics);

			graphics.Flush();

			String fileName = "image" + pageNumber.ToString() + ".png";

			bmp.Save(fileName, System.Drawing.Imaging.ImageFormat.Png);

			g.Dispose();

			bmp.Dispose();
		}

		private static void SaveEMF(Siberix.Report.IPage page, float scale, int pageNumber)
		{
			int width = (int)Siberix.Report.Utils.PointsToPixels(page.Width * scale);
			int height = (int)Siberix.Report.Utils.PointsToPixels(page.Height * scale);

			System.IO.MemoryStream ms = new System.IO.MemoryStream();

			System.Drawing.Bitmap bmp = new System.Drawing.Bitmap(1, 1, System.Drawing.Imaging.PixelFormat.Format24bppRgb);

			System.Drawing.Graphics g = System.Drawing.Graphics.FromImage(bmp);

			System.IntPtr hdc = g.GetHdc();

			System.Drawing.Imaging.Metafile metafile = new System.Drawing.Imaging.Metafile(ms, hdc, new System.Drawing.Rectangle(0, 0, width, height), System.Drawing.Imaging.MetafileFrameUnit.Pixel, System.Drawing.Imaging.EmfType.EmfPlusDual);

			g.ReleaseHdc(hdc);
			g.Dispose();

			bmp.Dispose();

			System.Drawing.Graphics gm = System.Drawing.Graphics.FromImage(metafile);

			Siberix.Wrappers.GDIPlus.Graphics graphics = new Siberix.Wrappers.GDIPlus.Graphics(gm);

			graphics.Scale(scale, scale);

			page.Draw(graphics);

			graphics.Flush();

			gm.Dispose();

			metafile.Dispose();

			String fileName = "image" + pageNumber.ToString() + ".emf";

			System.IO.FileStream fs = new System.IO.FileStream(fileName, System.IO.FileMode.Create, System.IO.FileAccess.Write);

			fs.Write(ms.ToArray(), 0, (int)ms.Length);

			fs.Close();
		}
	}
}