Imports System
Imports System.IO

Module Example

    Sub Main()

        ' Report
        Dim report As Siberix.Report.Report = New Siberix.Report.Report()

        ' Callback
        report.Callback = New Callback()

        ' Load
        report.Load("../../Catalog.xml")

        ' Publish
        report.Publish("Catalog.pdf", Siberix.Report.FileFormat.PDF)
        report.Publish("Catalog.xps", Siberix.Report.FileFormat.XPS)

        ' View
        Dim process As System.Diagnostics.Process = New System.Diagnostics.Process()
        Dim info As System.Diagnostics.ProcessStartInfo = New System.Diagnostics.ProcessStartInfo("Catalog.pdf")
        process.StartInfo = info
        process.Start()

    End Sub

    Public Class Callback
        Implements Siberix.Report.ICallback

        Public Sub New()

        End Sub

        Public Sub OnInjector(ByVal id As String, ByVal element As Siberix.Report.IElement) Implements Siberix.Report.ICallback.OnInjector

            If String.IsNullOrEmpty(id) Then
                Return
            End If


            If element.Type <> Siberix.Report.ElementType.Group Then

            End If

            Dim group As Siberix.Report.IGroup = CType(element, Siberix.Report.IGroup)

            If id.Equals("TOC") Then

                ' Styles
                Dim style1 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(8), Siberix.Graphics.Brushes.White)

                Dim xmlDoc As System.Xml.XmlDocument = New System.Xml.XmlDocument()

                xmlDoc.Load("../../Images/Description.xml")

                Dim grid As Siberix.Report.Grid.IGrid = group.AddGrid()
                grid.Spacings.Left = 5

                Dim column As Siberix.Report.Grid.IColumn = grid.AddColumn()
                column.Width = New Siberix.Report.RelativeWidth(90)

                column = grid.AddColumn()
                column.Width = New Siberix.Report.RelativeWidth(10)

                For Each category As System.Xml.XmlNode In xmlDoc.ChildNodes(1)

                    Dim xmlNode As System.Xml.XmlNode = category.Attributes.GetNamedItem("Name")

                    Dim row As Siberix.Report.Grid.IRow = grid.AddRow()
                    row.Spacings.Top = 5

                    Dim cell As Siberix.Report.Grid.ICell = row.AddCell()

                    Dim text As Siberix.Report.Text.IText = cell.AddText()
                    text.Style = style1
                    text.Width = New Siberix.Report.RelativeWidth(100)
                    text.AddContent(xmlNode.Value, New Siberix.Report.Text.Hyperlink(xmlNode.Value))
                    text.Leader = New Siberix.Report.Text.Leader(".")

                    cell = row.AddCell()

                    Dim pr As Siberix.Report.IPageReference = cell.AddPageReference(xmlNode.Value)
                    pr.Style = style1
                    pr.Alignment = Siberix.Report.NumberAlignment.Left

                Next

            End If

            If id.Equals("Items") Then

                ' Styles
                Dim style1 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(14), New Siberix.Graphics.SolidColorBrush(New Siberix.Graphics.Color(46, 0, 69)))
                Dim style2 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(12), New Siberix.Graphics.SolidColorBrush(New Siberix.Graphics.Color(46, 0, 69)))
                Dim style3 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.ArialBold(8), Siberix.Graphics.Brushes.Black)
                Dim style4 As Siberix.Report.Text.Style = New Siberix.Report.Text.Style(New Siberix.Graphics.Fonts.Arial(8), Siberix.Graphics.Brushes.Black)

                Dim xmlDoc As System.Xml.XmlDocument = New System.Xml.XmlDocument()

                xmlDoc.Load("../../Images/Description.xml")

                For Each category As System.Xml.XmlNode In xmlDoc.ChildNodes(1)

                    Dim xmlNode As System.Xml.XmlNode = category.Attributes.GetNamedItem("Name")

                    Dim text As Siberix.Report.Text.IText = group.AddText()
                    text.Style = style1
                    text.Id = xmlNode.Value
                    text.Spacings.Vertical = 10
                    text.AddContent(xmlNode.Value)

                    Dim first As Boolean = True

                    For Each ring As System.Xml.XmlNode In category.ChildNodes
                        If first Then

                            first = False

                            text.KeepWithNext = True
                        End If

                        Dim grid As Siberix.Report.Grid.IGrid = group.AddGrid()
                        grid.Spacings.Top = 5
                        grid.Spacings.Bottom = 5
                        grid.KeepSolid = True

                        Dim column As Siberix.Report.Grid.IColumn = grid.AddColumn()
                        column.Width = New Siberix.Report.RelativeWidth(30)

                        column = grid.AddColumn()
                        column.Width = New Siberix.Report.RelativeWidth(30)

                        column = grid.AddColumn()
                        column.Width = New Siberix.Report.RelativeWidth(40)

                        Dim row As Siberix.Report.Grid.IRow = grid.AddRow()

                        xmlNode = ring.Attributes.GetNamedItem("Image")

                        Dim cell As Siberix.Report.Grid.ICell = row.AddCell()
                        cell.RowSpan = 7
                        cell.Alignment.Horizontal = Siberix.Report.HorizontalAlignment.Center
                        cell.Alignment.Vertical = Siberix.Report.VerticalAlignment.Middle
                        cell.Borders = New Siberix.Report.Borders(New Siberix.Graphics.Pen(New Siberix.Graphics.Color(46, 0, 69), 1, Siberix.Graphics.DashStyle.Dot), 5)
                        cell.Paddings.All = 5

                        Dim img As Siberix.Report.IImage = cell.AddImage(New Siberix.Graphics.Image(xmlNode.Value))

                        xmlNode = ring.Attributes.GetNamedItem("Name")

                        cell = row.AddCell()
                        cell.Paddings.All = 5
                        cell.ColSpan = 2

                        text = cell.AddText()
                        text.Style = style2
                        text.Spacings.Left = 20
                        text.AddContent(xmlNode.Value)

                        row = grid.AddRow()

                        xmlNode = ring.Attributes.GetNamedItem("MetalType")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style3
                        text.Width = New Siberix.Report.RelativeWidth(100)
                        text.Alignment = Siberix.Report.TextAlignment.Right
                        text.AddContent("Metal Type :")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style4
                        text.AddContent(xmlNode.Value)

                        row = grid.AddRow()

                        xmlNode = ring.Attributes.GetNamedItem("BandWidth")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style3
                        text.Width = New Siberix.Report.RelativeWidth(100)
                        text.Alignment = Siberix.Report.TextAlignment.Right
                        text.AddContent("Band Width :")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style4
                        text.AddContent(xmlNode.Value)

                        row = grid.AddRow()

                        xmlNode = ring.Attributes.GetNamedItem("BandStyle")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style3
                        text.Width = New Siberix.Report.RelativeWidth(100)
                        text.Alignment = Siberix.Report.TextAlignment.Right
                        text.AddContent("Band Style :")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style4
                        text.AddContent(xmlNode.Value)

                        row = grid.AddRow()

                        xmlNode = ring.Attributes.GetNamedItem("MainStone")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style3
                        text.Width = New Siberix.Report.RelativeWidth(100)
                        text.Alignment = Siberix.Report.TextAlignment.Right
                        text.AddContent("Main Stone :")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style4
                        text.AddContent(xmlNode.Value)

                        row = grid.AddRow()

                        xmlNode = ring.Attributes.GetNamedItem("MainStoneSetting")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style3
                        text.Width = New Siberix.Report.RelativeWidth(100)
                        text.Alignment = Siberix.Report.TextAlignment.Right
                        text.AddContent("Main Stone Setting :")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style4
                        text.AddContent(xmlNode.Value)

                        row = grid.AddRow()

                        xmlNode = ring.Attributes.GetNamedItem("ItemWeight")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style3
                        text.Width = New Siberix.Report.RelativeWidth(100)
                        text.Alignment = Siberix.Report.TextAlignment.Right
                        text.AddContent("Item Weight :")

                        cell = row.AddCell()
                        cell.Paddings.All = 2

                        text = cell.AddText()
                        text.Style = style4
                        text.AddContent(xmlNode.Value)

                    Next

                Next

            End If

        End Sub

        Public Sub OnInjector(ByVal name As String, ByVal text As Siberix.Report.Text.IText, ByVal style As Siberix.Report.Text.Style, ByVal hyperlink As Siberix.Report.Text.Hyperlink) Implements Siberix.Report.ICallback.OnInjector

        End Sub

        Public Function OnMergeCode(ByVal name As String) As String Implements Siberix.Report.ICallback.OnMergeCode

            Return ""

        End Function

        Public Function OnDrawing(ByVal name As String) As Siberix.Report.IDrawing Implements Siberix.Report.ICallback.OnDrawing

            Return Nothing

        End Function

        Public Function ResolvePath(ByVal path As String) As String Implements Siberix.Report.ICallback.ResolvePath

            Return path

        End Function

        Public Function GetStyle(ByVal name As String) As Siberix.Report.Text.Style Implements Siberix.Report.ICallback.GetStyle

            Return Nothing

        End Function

        Public Function LoadFont(ByVal path As String) As Stream Implements Siberix.Report.ICallback.LoadFont

            Return Nothing

        End Function

        Public Function LoadImage(ByVal path As String) As Stream Implements Siberix.Report.ICallback.LoadImage

            Return Nothing

        End Function

        Public Function LoadMetafile(ByVal path As String) As Stream Implements Siberix.Report.ICallback.LoadMetafile

            Return Nothing

        End Function

        Public Sub OnLoadStart(ByVal element As Siberix.Report.IElement) Implements Siberix.Report.ICallback.OnLoadStart

        End Sub

        Public Sub OnLoadEnd(ByVal element As Siberix.Report.IElement) Implements Siberix.Report.ICallback.OnLoadEnd

        End Sub

    End Class

End Module
